diff --git a/Code/Visu/otbHistogramAndTransfertFunctionWidget.h b/Code/Visu/otbHistogramAndTransfertFunctionWidget.h
index 1c24d4cda873665befb333e24a2cf14a4937f607..bd3fae97205c4b91c4a0600bb0e106d93dd845ee 100644
--- a/Code/Visu/otbHistogramAndTransfertFunctionWidget.h
+++ b/Code/Visu/otbHistogramAndTransfertFunctionWidget.h
@@ -15,31 +15,31 @@ the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 PURPOSE.  See the above copyright notices for more information.
 
 =========================================================================*/
-#ifndef _otbHistogramAndTransfertFunctionWidget_h
-#define _otbHistogramAndTransfertFunctionWidget_h
+#ifndef _otbHistogramAndTransferFunctionWidget_h
+#define _otbHistogramAndTransferFunctionWidget_h
 
 #include "itkProcessObject.h"
 #include "itkFixedArray.h"
-#include "otbImageWidgetTransfertFunction.h"
+#include "otbImageWidgetTransferFunction.h"
 #include "FL/Fl_Gl_Window.H"
 #include "otbMacro.h"
 
 
 namespace otb
 {
-/** \class HistogramAndTransfertFunctionWidget
+/** \class HistogramAndTransferFunctionWidget
  *  \brief 
  *
  * \ingroup 
  * \ingroup
  */
 template <class THistogram, class TPixel>
-class ITK_EXPORT HistogramAndTransfertFunctionWidget
+class ITK_EXPORT HistogramAndTransferFunctionWidget
   : public Fl_Gl_Window, public itk::ProcessObject
 {
  public:
   /** Standard typedefs */
-  typedef HistogramAndTransfertFunctionWidget Self;
+  typedef HistogramAndTransferFunctionWidget Self;
   typedef itk::ProcessObject                  Superclass;
   typedef itk::SmartPointer<Self>             Pointer;
   typedef itk::SmartPointer<const Self>       ConstPointer;
@@ -48,7 +48,7 @@ class ITK_EXPORT HistogramAndTransfertFunctionWidget
   itkNewMacro(Self);
   
   /** Creation through object factory macro */
-  itkTypeMacro(HistogramAndTransfertFunctionWidget,ProcessObject);
+  itkTypeMacro(HistogramAndTransferFunctionWidget,ProcessObject);
   
   /** Template parameters typedefs */
   typedef TPixel PixelType;
@@ -59,18 +59,18 @@ class ITK_EXPORT HistogramAndTransfertFunctionWidget
   typedef typename HistogramType::ConstIterator HistogramIteratorType;
   typedef itk::FixedArray<double,3> ColorType;
 
-  typedef otb::ImageWidgetTransfertFunction<PixelType> TransfertFunctionType;
-  typedef typename TransfertFunctionType::Pointer TransfertFunctionPointerType;
-  typedef otb::ImageWidgetAffineTransfertFunction<PixelType> AffineTransfertFunctionType;
+  typedef otb::ImageWidgetTransferFunction<PixelType> TransferFunctionType;
+  typedef typename TransferFunctionType::Pointer TransferFunctionPointerType;
+  typedef otb::ImageWidgetAffineTransferFunction<PixelType> AffineTransferFunctionType;
 
 
   itkSetMacro(Histogram,HistogramConstPointerType);
   itkGetMacro(Histogram,HistogramConstPointerType);
-  itkGetMacro(TransfertFunction,TransfertFunctionPointerType);
+  itkGetMacro(TransferFunction,TransferFunctionPointerType);
   
-  virtual void SetTransfertFunction(TransfertFunctionType * function)
+  virtual void SetTransferFunction(TransferFunctionType * function)
     {
-      m_TransfertFunction = function;
+      m_TransferFunction = function;
       this->Modified();
     }
 
@@ -82,13 +82,13 @@ class ITK_EXPORT HistogramAndTransfertFunctionWidget
   itkGetMacro(AxisColor,ColorType);
   itkSetMacro(TextColor,ColorType);
   itkGetMacro(TextColor,ColorType);
-  itkSetMacro(TransfertFunctionColor,ColorType);
-  itkGetMacro(TransfertFunctionColor,ColorType);
+  itkSetMacro(TransferFunctionColor,ColorType);
+  itkGetMacro(TransferFunctionColor,ColorType);
   
   itkSetMacro(Label,std::string);
   itkGetMacro(Label,std::string);
-  itkSetMacro(TransfertFunctionLabel,std::string);
-  itkGetMacro(TransfertFunctionLabel,std::string);
+  itkSetMacro(TransferFunctionLabel,std::string);
+  itkGetMacro(TransferFunctionLabel,std::string);
 
   itkSetMacro(MarginX,double);
   itkGetMacro(MarginX,double);
@@ -104,9 +104,9 @@ class ITK_EXPORT HistogramAndTransfertFunctionWidget
   
 protected:
   /** Constructor */
-  HistogramAndTransfertFunctionWidget();
+  HistogramAndTransferFunctionWidget();
   /** Destructor */
-  virtual ~HistogramAndTransfertFunctionWidget() {};
+  virtual ~HistogramAndTransferFunctionWidget() {};
  /**PrintSelf method */
   virtual void PrintSelf(std::ostream& os, itk::Indent indent) const;
 
@@ -123,23 +123,23 @@ protected:
 
   virtual void LegendRendering(double gridXSpacing, double gridYSpacing, double maxFrequency);
   
-  virtual void TransfertFunctionRendering(void);
+  virtual void TransferFunctionRendering(void);
 
   virtual void OutputHistogramRendering(void);
 
   virtual void BoundRendering(void);
 
-  virtual void TransfertFunctionLabelRendering(void);
+  virtual void TransferFunctionLabelRendering(void);
 
 private:
-  HistogramAndTransfertFunctionWidget(const Self&); //purposely not implemented
+  HistogramAndTransferFunctionWidget(const Self&); //purposely not implemented
   void operator=(const Self&); //purposely not implemented
 
   /** The histogram to draw */
   HistogramConstPointerType m_Histogram;
 
   /** The transfert function */
-  TransfertFunctionPointerType m_TransfertFunction;
+  TransferFunctionPointerType m_TransferFunction;
 
   /** Colors */
   ColorType m_HistogramColor;
@@ -147,7 +147,7 @@ private:
   ColorType m_AxisColor;
   ColorType m_GridColor;
   ColorType m_TextColor;
-  ColorType m_TransfertFunctionColor;
+  ColorType m_TransferFunctionColor;
   ColorType m_BoundColor;
   /** Margin around histogram */
   double m_MarginX;
@@ -163,12 +163,12 @@ private:
   /** Label of the histogram */
   std::string m_Label;
 /** Label of the histogram */
-  std::string m_TransfertFunctionLabel;
+  std::string m_TransferFunctionLabel;
   
 };
 }// End namespace otb
 #ifndef OTB_MANUAL_INSTANTIATION
-#include "otbHistogramAndTransfertFunctionWidget.txx"
+#include "otbHistogramAndTransferFunctionWidget.txx"
 #endif
 
 #endif
diff --git a/Code/Visu/otbHistogramAndTransfertFunctionWidget.txx b/Code/Visu/otbHistogramAndTransfertFunctionWidget.txx
index bb46f444c3fabe59c6e6d591f98398d687530b64..8fbfc9fb57fa051f3fbde40aa5bbfc9320ffbe20 100644
--- a/Code/Visu/otbHistogramAndTransfertFunctionWidget.txx
+++ b/Code/Visu/otbHistogramAndTransfertFunctionWidget.txx
@@ -15,10 +15,10 @@ the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 PURPOSE.  See the above copyright notices for more information.
 
 =========================================================================*/
-#ifndef _otbHistogramAndTransfertFunctionWidget_txx
-#define _otbHistogramAndTransfertFunctionWidget_txx
+#ifndef _otbHistogramAndTransferFunctionWidget_txx
+#define _otbHistogramAndTransferFunctionWidget_txx
 
-#include "otbHistogramAndTransfertFunctionWidget.h"
+#include "otbHistogramAndTransferFunctionWidget.h"
 #include <FL/gl.h>
 #include <FL/Fl.H>
 
@@ -26,12 +26,12 @@ namespace otb
 {
 
 template <class THistogram, class TPixel>
-HistogramAndTransfertFunctionWidget<THistogram,TPixel>
-::HistogramAndTransfertFunctionWidget()
+HistogramAndTransferFunctionWidget<THistogram,TPixel>
+::HistogramAndTransferFunctionWidget()
   : Fl_Gl_Window(0,0,0,0,0)
 {
   m_Label = "Default label";
-  m_TransfertFunctionLabel = "Function label";
+  m_TransferFunctionLabel = "Function label";
   m_HistogramColor[0]=0.5;
   m_HistogramColor[1]=0.5;
   m_HistogramColor[2]=0.5;
@@ -47,13 +47,13 @@ HistogramAndTransfertFunctionWidget<THistogram,TPixel>
   m_GridColor[0]=0.75;
   m_GridColor[1]=0.75;
   m_GridColor[2]=0.75;
-  m_TransfertFunctionColor[0]=1;
-  m_TransfertFunctionColor[1]=0;
-  m_TransfertFunctionColor[2]=0;
+  m_TransferFunctionColor[0]=1;
+  m_TransferFunctionColor[1]=0;
+  m_TransferFunctionColor[2]=0;
   m_BoundColor[0]=0;
   m_BoundColor[1]=1;
   m_BoundColor[2]=0;
-  m_TransfertFunction = NULL;
+  m_TransferFunction = NULL;
   m_Histogram = NULL;
   m_MarginX = 30;
   m_MarginY = 30;
@@ -67,7 +67,7 @@ HistogramAndTransfertFunctionWidget<THistogram,TPixel>
 
 template <class THistogram, class TPixel>
 void
-HistogramAndTransfertFunctionWidget<THistogram,TPixel>
+HistogramAndTransferFunctionWidget<THistogram,TPixel>
 ::OpenGlSetup()
 {
   if (!this->valid())
@@ -92,7 +92,7 @@ HistogramAndTransfertFunctionWidget<THistogram,TPixel>
 
 template <class THistogram, class TPixel>
 void
-HistogramAndTransfertFunctionWidget<THistogram,TPixel>
+HistogramAndTransferFunctionWidget<THistogram,TPixel>
 ::GridRendering(double gridXSpacing, double gridYSpacing)
 {
   double x,y;
@@ -121,7 +121,7 @@ HistogramAndTransfertFunctionWidget<THistogram,TPixel>
 
 template <class THistogram, class TPixel>
 void
-HistogramAndTransfertFunctionWidget<THistogram,TPixel>
+HistogramAndTransferFunctionWidget<THistogram,TPixel>
 ::AxisRendering(void)
 {
   glBegin(GL_LINES);
@@ -135,7 +135,7 @@ HistogramAndTransfertFunctionWidget<THistogram,TPixel>
 
 template <class THistogram, class TPixel>
 void
-HistogramAndTransfertFunctionWidget<THistogram,TPixel>
+HistogramAndTransferFunctionWidget<THistogram,TPixel>
 ::HistogramRendering(double binWidth, double binHeightRatio, double maxFrequency)
 {
   HistogramIteratorType it;
@@ -165,7 +165,7 @@ HistogramAndTransfertFunctionWidget<THistogram,TPixel>
 
 template <class THistogram, class TPixel>
 void
-HistogramAndTransfertFunctionWidget<THistogram,TPixel>
+HistogramAndTransferFunctionWidget<THistogram,TPixel>
 ::BoundRendering(void)
 {
   double x,y;
@@ -176,13 +176,13 @@ HistogramAndTransfertFunctionWidget<THistogram,TPixel>
   double factor = (m_Histogram->Quantile(0,1.)-m_Histogram->Quantile(0,0.))
     /(static_cast<double>(this->w())-2*m_MarginX-m_OutputHistogramMargin*static_cast<double>(this->w()));
 
-  x = m_MarginX + static_cast<double>(m_TransfertFunction->GetLowerBound()-m_Histogram->Quantile(0,0.))/factor;
+  x = m_MarginX + static_cast<double>(m_TransferFunction->GetLowerBound()-m_Histogram->Quantile(0,0.))/factor;
   
   y = m_MarginY;
   glVertex2d(x,y);
   y = static_cast<double>(this->h())-m_MarginY;
   glVertex2d(x,y);
-  x = m_MarginX + static_cast<double>(m_TransfertFunction->GetUpperBound()-m_Histogram->Quantile(0,0.))/factor;
+  x = m_MarginX + static_cast<double>(m_TransferFunction->GetUpperBound()-m_Histogram->Quantile(0,0.))/factor;
   glVertex2d(x,y);
   y=  m_MarginY;
   glVertex2d(x,y);
@@ -192,7 +192,7 @@ HistogramAndTransfertFunctionWidget<THistogram,TPixel>
 
 template <class THistogram, class TPixel>
 void
-HistogramAndTransfertFunctionWidget<THistogram,TPixel>
+HistogramAndTransferFunctionWidget<THistogram,TPixel>
 ::LegendRendering(double gridXSpacing, double gridYSpacing, double maxFrequency)
 {
   double x,y;
@@ -231,10 +231,10 @@ HistogramAndTransfertFunctionWidget<THistogram,TPixel>
 
 template <class THistogram, class TPixel>
 void
-HistogramAndTransfertFunctionWidget<THistogram,TPixel>
-::TransfertFunctionRendering()
+HistogramAndTransferFunctionWidget<THistogram,TPixel>
+::TransferFunctionRendering()
 {
-  glColor3d(m_TransfertFunctionColor[0],m_TransfertFunctionColor[1],m_TransfertFunctionColor[2]);
+  glColor3d(m_TransferFunctionColor[0],m_TransferFunctionColor[1],m_TransferFunctionColor[2]);
   glBegin(GL_LINE_STRIP);
   double x,y;
   double step = (m_Histogram->Quantile(0,1.)-m_Histogram->Quantile(0,0.))
@@ -247,7 +247,7 @@ HistogramAndTransfertFunctionWidget<THistogram,TPixel>
 					       +static_cast<double>(i)*step);
 
       x = m_MarginX + static_cast<double>(i)*xscale;
-      y = m_MarginY + yscale * static_cast<double>(m_TransfertFunction->Map(value));
+      y = m_MarginY + yscale * static_cast<double>(m_TransferFunction->Map(value));
       glVertex2d(x,y);
     }
   glEnd();
@@ -255,7 +255,7 @@ HistogramAndTransfertFunctionWidget<THistogram,TPixel>
 
 template <class THistogram, class TPixel>
 void
-HistogramAndTransfertFunctionWidget<THistogram,TPixel>
+HistogramAndTransferFunctionWidget<THistogram,TPixel>
 ::OutputHistogramRendering()
 {
   std::vector<unsigned int> outputHistogram(256,0);
@@ -263,7 +263,7 @@ HistogramAndTransfertFunctionWidget<THistogram,TPixel>
   HistogramIteratorType it;
   for(it=m_Histogram->Begin();it!=m_Histogram->End();++it)
     {
-      outputHistogram[m_TransfertFunction->Map(static_cast<PixelType>(it.GetMeasurementVector()[0]))]+=static_cast<unsigned int>(it.GetFrequency());
+      outputHistogram[m_TransferFunction->Map(static_cast<PixelType>(it.GetMeasurementVector()[0]))]+=static_cast<unsigned int>(it.GetFrequency());
     }
   // Setting the extremity to 0 to avoid sides effect
   outputHistogram[0]=0;
@@ -292,7 +292,7 @@ HistogramAndTransfertFunctionWidget<THistogram,TPixel>
      for(vit=outputHistogram.begin();vit!=outputHistogram.end();++vit,starty+=binWidth)
        {
 	 glBegin(GL_POLYGON);
-	 glColor3d(m_TransfertFunctionColor[0],m_TransfertFunctionColor[1],m_TransfertFunctionColor[2]);
+	 glColor3d(m_TransferFunctionColor[0],m_TransferFunctionColor[1],m_TransferFunctionColor[2]);
 	 
 	 x =static_cast<double>(this->w())-m_OutputHistogramMargin*static_cast<double>(this->w())-m_MarginX/2;
 	 y = starty;
@@ -322,19 +322,19 @@ HistogramAndTransfertFunctionWidget<THistogram,TPixel>
 
 template <class THistogram, class TPixel>
 void
-HistogramAndTransfertFunctionWidget<THistogram,TPixel>
-::TransfertFunctionLabelRendering(void)
+HistogramAndTransferFunctionWidget<THistogram,TPixel>
+::TransferFunctionLabelRendering(void)
 {
  //rendering label
  gl_font(FL_COURIER_BOLD,12);
- gl_draw(m_TransfertFunctionLabel.c_str(),static_cast<float>(this->w()-m_MarginX/2-m_OutputHistogramMargin*static_cast<double>(this->w())),static_cast<float>(m_MarginY/2));
+ gl_draw(m_TransferFunctionLabel.c_str(),static_cast<float>(this->w()-m_MarginX/2-m_OutputHistogramMargin*static_cast<double>(this->w())),static_cast<float>(m_MarginY/2));
 
 }
 
 
 template <class THistogram, class TPixel>
 void
-HistogramAndTransfertFunctionWidget<THistogram,TPixel>
+HistogramAndTransferFunctionWidget<THistogram,TPixel>
 ::draw()
 {
   if(!m_Histogram)
@@ -371,19 +371,19 @@ HistogramAndTransfertFunctionWidget<THistogram,TPixel>
   LegendRendering(gridXSpacing,gridYSpacing,maxFrequency);
  
 
-  if(m_TransfertFunction)
+  if(m_TransferFunction)
     {
       BoundRendering();
-      TransfertFunctionRendering();
+      TransferFunctionRendering();
       OutputHistogramRendering();
-      TransfertFunctionLabelRendering();
+      TransferFunctionLabelRendering();
     }
   m_Updating = false;
 }
 
 template <class THistogram, class TPixel>
 void
-HistogramAndTransfertFunctionWidget<THistogram,TPixel>
+HistogramAndTransferFunctionWidget<THistogram,TPixel>
 ::PrintSelf(std::ostream& os, itk::Indent indent) const
 {
   Superclass::PrintSelf(os,indent);
diff --git a/Code/Visu/otbImageViewerBase.txx b/Code/Visu/otbImageViewerBase.txx
index 5099acc6c903189fe542bec177fd4f71ee4b5790..5c701eb7f07a7a5c5dadb9e65f1c2b08199f279d 100644
--- a/Code/Visu/otbImageViewerBase.txx
+++ b/Code/Visu/otbImageViewerBase.txx
@@ -69,7 +69,7 @@ namespace otb
     m_PolygonalROISelectionMode = false;
     m_UseImageOverlay = false;
     m_HistogramGeneratorList=HistogramGeneratorListType::New();
-    m_TransfertFunctionList = TransfertFunctionListType::New();
+    m_TransferFunctionList = TransferFunctionListType::New();
     m_RedHistogramWidget = HistogramWidgetType::New();
     m_GreenHistogramWidget = HistogramWidgetType::New();
     m_BlueHistogramWidget = HistogramWidgetType::New();
@@ -156,7 +156,7 @@ namespace otb
     }
 
   m_HistogramGeneratorList->Clear();
-  m_TransfertFunctionList->Clear();
+  m_TransferFunctionList->Clear();
   otbMsgDebugMacro(<<"Nb bands: "<<m_InputImage->GetNumberOfComponentsPerPixel());
   
   for(unsigned int i = 0;i<sl->Size();++i)
@@ -169,19 +169,19 @@ namespace otb
       generator->SetNumberOfBins(size);
       generator->Update();
       m_HistogramGeneratorList->PushBack(generator);
-      m_TransfertFunctionList->PushBack(AffineTransfertFunctionType::New());
+      m_TransferFunctionList->PushBack(AffineTransferFunctionType::New());
       double min = generator->GetOutput()->Quantile(0,m_NormalizationFactor);
       double max = generator->GetOutput()->Quantile(0,1-m_NormalizationFactor);
-      m_TransfertFunctionList->Back()->SetLowerBound(static_cast<InputPixelType>(min));
-      m_TransfertFunctionList->Back()->SetUpperBound(static_cast<InputPixelType>(max));
+      m_TransferFunctionList->Back()->SetLowerBound(static_cast<InputPixelType>(min));
+      m_TransferFunctionList->Back()->SetUpperBound(static_cast<InputPixelType>(max));
     }
 
   if(m_UseScroll)
     {
-      m_ScrollWidget->SetTransfertFunctionList(m_TransfertFunctionList);
+      m_ScrollWidget->SetTransferFunctionList(m_TransferFunctionList);
     }
-  m_ZoomWidget->SetTransfertFunctionList(m_TransfertFunctionList);
-  m_FullWidget->SetTransfertFunctionList(m_TransfertFunctionList);
+  m_ZoomWidget->SetTransferFunctionList(m_TransferFunctionList);
+  m_FullWidget->SetTransferFunctionList(m_TransferFunctionList);
   }
   
   /// Build the HMI
@@ -1077,22 +1077,22 @@ ImageViewerBase<TPixel,TLabel>
 	  blue[2]=0.5;
 
 	  m_RedHistogramWidget->SetHistogram(m_HistogramGeneratorList->GetNthElement(m_RedChannelIndex)->GetOutput());
-	  m_RedHistogramWidget->SetTransfertFunction(m_TransfertFunctionList->GetNthElement(m_RedChannelIndex));
+	  m_RedHistogramWidget->SetTransferFunction(m_TransferFunctionList->GetNthElement(m_RedChannelIndex));
 	  m_RedHistogramWidget->SetLabel("Red channel");
-	  m_RedHistogramWidget->SetTransfertFunctionLabel("Affine");
+	  m_RedHistogramWidget->SetTransferFunctionLabel("Affine");
 	  m_RedHistogramWidget->SetHistogramColor(red);
 	  m_RedHistogramWidget->SetTextColor(red);
 	  
 	  m_BlueHistogramWidget->SetHistogram(m_HistogramGeneratorList->GetNthElement(m_BlueChannelIndex)->GetOutput());
-	  m_BlueHistogramWidget->SetTransfertFunction(m_TransfertFunctionList->GetNthElement(m_BlueChannelIndex));
+	  m_BlueHistogramWidget->SetTransferFunction(m_TransferFunctionList->GetNthElement(m_BlueChannelIndex));
 	  m_BlueHistogramWidget->SetLabel("Blue channel");
-	  m_BlueHistogramWidget->SetTransfertFunctionLabel("Affine");
+	  m_BlueHistogramWidget->SetTransferFunctionLabel("Affine");
 	  m_BlueHistogramWidget->SetHistogramColor(blue);
 	  m_BlueHistogramWidget->SetTextColor(blue);
 	  m_GreenHistogramWidget->SetHistogram(m_HistogramGeneratorList->GetNthElement(m_GreenChannelIndex)->GetOutput());
-	  m_GreenHistogramWidget->SetTransfertFunction(m_TransfertFunctionList->GetNthElement(m_GreenChannelIndex));
+	  m_GreenHistogramWidget->SetTransferFunction(m_TransferFunctionList->GetNthElement(m_GreenChannelIndex));
 	  m_GreenHistogramWidget->SetLabel("Green channel");
-	  m_GreenHistogramWidget->SetTransfertFunctionLabel("Affine");
+	  m_GreenHistogramWidget->SetTransferFunctionLabel("Affine");
 	  m_GreenHistogramWidget->SetHistogramColor(green);
 	  m_GreenHistogramWidget->SetTextColor(green);
 	  break;
@@ -1116,9 +1116,9 @@ ImageViewerBase<TPixel,TLabel>
       gray.Fill(0.5);
       
       m_RedHistogramWidget->SetHistogram(m_HistogramGeneratorList->GetNthElement(m_RedChannelIndex)->GetOutput());
-      m_RedHistogramWidget->SetTransfertFunction(m_TransfertFunctionList->GetNthElement(m_RedChannelIndex));
+      m_RedHistogramWidget->SetTransferFunction(m_TransferFunctionList->GetNthElement(m_RedChannelIndex));
       m_RedHistogramWidget->SetLabel("Grayscale channel");
-      m_RedHistogramWidget->SetTransfertFunctionLabel("Affine");
+      m_RedHistogramWidget->SetTransferFunctionLabel("Affine");
       m_RedHistogramWidget->SetHistogramColor(gray);
       m_RedHistogramWidget->SetTextColor(gray);
       break;
@@ -1144,9 +1144,9 @@ ImageViewerBase<TPixel,TLabel>
       gray.Fill(0.5);
       
       m_RedHistogramWidget->SetHistogram(m_HistogramGeneratorList->GetNthElement(0)->GetOutput());
-      m_RedHistogramWidget->SetTransfertFunction(m_TransfertFunctionList->GetNthElement(0));
+      m_RedHistogramWidget->SetTransferFunction(m_TransferFunctionList->GetNthElement(0));
       m_RedHistogramWidget->SetLabel("Modulus");
-      m_RedHistogramWidget->SetTransfertFunctionLabel("Affine");
+      m_RedHistogramWidget->SetTransferFunctionLabel("Affine");
       m_RedHistogramWidget->SetHistogramColor(gray);
       m_RedHistogramWidget->SetTextColor(gray);
       break;
@@ -1172,9 +1172,9 @@ ImageViewerBase<TPixel,TLabel>
       gray.Fill(0.5);
       
       m_RedHistogramWidget->SetHistogram(m_HistogramGeneratorList->GetNthElement(0)->GetOutput());
-      m_RedHistogramWidget->SetTransfertFunction(m_TransfertFunctionList->GetNthElement(0));
+      m_RedHistogramWidget->SetTransferFunction(m_TransferFunctionList->GetNthElement(0));
       m_RedHistogramWidget->SetLabel("Phase");
-      m_RedHistogramWidget->SetTransfertFunctionLabel("Affine");
+      m_RedHistogramWidget->SetTransferFunctionLabel("Affine");
       m_RedHistogramWidget->SetHistogramColor(gray);
       m_RedHistogramWidget->SetTextColor(gray);
       break;
@@ -1214,13 +1214,13 @@ ImageViewerBase<TPixel,TLabel>
 template<class TPixel, class TLabel>
 void
 ImageViewerBase<TPixel,TLabel>
-::ChangeTransfertFunctions(void)
+::ChangeTransferFunctions(void)
 {
-  m_TransfertFunctionList->SetNthElement(m_RedChannelIndex, m_RedHistogramWidget->GetTransfertFunction());
+  m_TransferFunctionList->SetNthElement(m_RedChannelIndex, m_RedHistogramWidget->GetTransferFunction());
   if(m_FullWidget->GetViewModel()==ScrollWidgetType::RGB)
     {
-      m_TransfertFunctionList->SetNthElement(m_BlueChannelIndex, m_BlueHistogramWidget->GetTransfertFunction());
-      m_TransfertFunctionList->SetNthElement(m_GreenChannelIndex, m_GreenHistogramWidget->GetTransfertFunction());
+      m_TransferFunctionList->SetNthElement(m_BlueChannelIndex, m_BlueHistogramWidget->GetTransferFunction());
+      m_TransferFunctionList->SetNthElement(m_GreenChannelIndex, m_GreenHistogramWidget->GetTransferFunction());
     }
   m_FullWidget->ClearBufferedRegion();
   m_ZoomWidget->ClearBufferedRegion();
diff --git a/Code/Visu/otbImageWidgetBase.h b/Code/Visu/otbImageWidgetBase.h
index df5693fe159b74206f687fe3034c4e299b153a7d..6576a5d448a991d06b3811b31032af1e0cd0f45c 100644
--- a/Code/Visu/otbImageWidgetBase.h
+++ b/Code/Visu/otbImageWidgetBase.h
@@ -24,7 +24,7 @@
 #include "itkObject.h"
 #include "otbList.h"
 #include "otbImageWidgetFormBase.h"
-#include "otbImageWidgetTransfertFunction.h"
+#include "otbImageWidgetTransferFunction.h"
 
 namespace otb
 {
@@ -69,10 +69,10 @@ class ImageWidgetBase
     typedef typename FormListType::ReverseIterator ReverseIteratorType;
     typedef typename FormListType::Iterator IteratorType;
 
-    typedef otb::ImageWidgetTransfertFunction<PixelType> TransfertFunctionType;
-    typedef otb::ImageWidgetAffineTransfertFunction<PixelType> AffineTransfertFunctionType;
-    typedef List<TransfertFunctionType> TransfertFunctionListType;
-    typedef typename TransfertFunctionListType::Pointer TransfertFunctionListPointerType;
+    typedef otb::ImageWidgetTransferFunction<PixelType> TransferFunctionType;
+    typedef otb::ImageWidgetAffineTransferFunction<PixelType> AffineTransferFunctionType;
+    typedef List<TransferFunctionType> TransferFunctionListType;
+    typedef typename TransferFunctionListType::Pointer TransferFunctionListPointerType;
     
     itkSetMacro(BufferedRegion,RegionType);
     itkGetMacro(BufferedRegion,RegionType);
@@ -108,7 +108,7 @@ class ImageWidgetBase
     itkSetMacro(ImageOverlayOpacity,unsigned char);
 
     itkGetObjectMacro(FormList,FormListType);
-    itkGetObjectMacro(TransfertFunctionList,TransfertFunctionListType);
+    itkGetObjectMacro(TransferFunctionList,TransferFunctionListType);
 
     itkGetMacro(OpenGlIsotropicZoom,double);
     
@@ -138,7 +138,7 @@ class ImageWidgetBase
     /** Set the transfert function list
      *  \param list The transfert function list.
      */
-    void SetTransfertFunctionList(TransfertFunctionListType * list);
+    void SetTransferFunctionList(TransferFunctionListType * list);
 
     /** Show The widget */
     void Show(void);
@@ -233,7 +233,7 @@ class ImageWidgetBase
       */
      unsigned int m_SubSamplingRate;
      /** List of the transfert function by channel */
-     TransfertFunctionListPointerType m_TransfertFunctionList;
+     TransferFunctionListPointerType m_TransferFunctionList;
   };
 } // end namespace otb
 
diff --git a/Code/Visu/otbImageWidgetBase.txx b/Code/Visu/otbImageWidgetBase.txx
index 61dcb46e9ae5e149661016fb0f3c6dabac387529..3983a0931f0e88fb4e6a14b9379fb5a3d6308d25 100644
--- a/Code/Visu/otbImageWidgetBase.txx
+++ b/Code/Visu/otbImageWidgetBase.txx
@@ -55,8 +55,8 @@ ImageWidgetBase<TPixel>
   m_ImageOverlay = NULL;
   m_OpenGlImageOverlayBuffer = NULL;
   m_ImageOverlayOpacity = 128;
-  m_TransfertFunctionList = TransfertFunctionListType::New();
-  m_TransfertFunctionList->PushBack(AffineTransfertFunctionType::New());
+  m_TransferFunctionList = TransferFunctionListType::New();
+  m_TransferFunctionList->PushBack(AffineTransferFunctionType::New());
   m_SubSamplingRate = 1;
 }
 /**
@@ -110,9 +110,9 @@ ImageWidgetBase<TPixel>
 {
   for(unsigned int i = 0; i<m_Image->GetNumberOfComponentsPerPixel();++i)
     {
-      if(i>=m_TransfertFunctionList->Size())
+      if(i>=m_TransferFunctionList->Size())
 	{
-	  m_TransfertFunctionList->PushBack(AffineTransfertFunctionType::New());
+	  m_TransferFunctionList->PushBack(AffineTransferFunctionType::New());
 	}
     }
 }
@@ -220,9 +220,9 @@ ImageWidgetBase<TPixel>
 template <class TPixel>
 void
 ImageWidgetBase<TPixel>
-::SetTransfertFunctionList(TransfertFunctionListType * list)
+::SetTransferFunctionList(TransferFunctionListType * list)
 {
-  m_TransfertFunctionList = list;
+  m_TransferFunctionList = list;
 }
 
 /** Get the input overlay image.
@@ -263,7 +263,7 @@ unsigned char
 ImageWidgetBase<TPixel>
 ::Normalize(PixelType value, unsigned int channelIndex)
 {
-  return m_TransfertFunctionList->GetNthElement(channelIndex)->Map(value);
+  return m_TransferFunctionList->GetNthElement(channelIndex)->Map(value);
 }
 
 /** 
diff --git a/Code/Visu/otbImageWidgetTransfertFunction.h b/Code/Visu/otbImageWidgetTransfertFunction.h
index 2d3bb9b2b92b99916a93429b5e9a10fee6d0fe2a..a6c87f11fd99a541445e6ed0809614eac8e2b14f 100644
--- a/Code/Visu/otbImageWidgetTransfertFunction.h
+++ b/Code/Visu/otbImageWidgetTransfertFunction.h
@@ -15,8 +15,8 @@ the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 PURPOSE.  See the above copyright notices for more information.
 
 =========================================================================*/
-#ifndef _otbImageWidgetTransfertFunction_h
-#define _otbImageWidgetTransfertFunction_h
+#ifndef _otbImageWidgetTransferFunction_h
+#define _otbImageWidgetTransferFunction_h
 
 #include "itkProcessObject.h"
 #include "itkMacro.h"
@@ -24,22 +24,22 @@ PURPOSE.  See the above copyright notices for more information.
 
 namespace otb
 {
-/** \class ImageWidgetTransfertFunction
+/** \class ImageWidgetTransferFunction
  *  \brief Base class for visualisation transfert functions.
  */
 template <class TPixel>
-class ITK_EXPORT ImageWidgetTransfertFunction
+class ITK_EXPORT ImageWidgetTransferFunction
   : public itk::Object
 {
  public:
   /** Standard typedefs */
-  typedef ImageWidgetTransfertFunction      Self;
+  typedef ImageWidgetTransferFunction      Self;
   typedef itk::Object                       Superclass;
   typedef itk::SmartPointer<Self>           Pointer;
   typedef itk::SmartPointer<const Self>     ConstPointer;
   
   /** Creation through object factory macro */
-  itkTypeMacro(ImageWidgetTransfertFunction,Object);
+  itkTypeMacro(ImageWidgetTransferFunction,Object);
   
   /** Template parameters typedefs */
   typedef TPixel PixelType;
@@ -60,13 +60,13 @@ class ITK_EXPORT ImageWidgetTransfertFunction
 
 protected:
   /** Constructor */
-  ImageWidgetTransfertFunction()
+  ImageWidgetTransferFunction()
     {
       m_LowerBound = 0;
       m_UpperBound = 255;
     }
   /** Destructor */
-  virtual ~ImageWidgetTransfertFunction() {}
+  virtual ~ImageWidgetTransferFunction() {}
  /**PrintSelf method */
   virtual void PrintSelf(std::ostream& os, itk::Indent indent) const
     {
@@ -76,7 +76,7 @@ protected:
     }
 
 private:
-  ImageWidgetTransfertFunction(const Self&); //purposely not implemented
+  ImageWidgetTransferFunction(const Self&); //purposely not implemented
   void operator=(const Self&); //purposely not implemented
 
   /// lower bound (set to 0)
@@ -85,17 +85,17 @@ private:
   PixelType m_UpperBound;
 };
 
-/** \class ImageWidgetAffineTransfertFunction
+/** \class ImageWidgetAffineTransferFunction
  *  \brief Affine transfert function.
  */
 template <class TPixel>
-class ITK_EXPORT ImageWidgetAffineTransfertFunction
-  : public ImageWidgetTransfertFunction<TPixel>
+class ITK_EXPORT ImageWidgetAffineTransferFunction
+  : public ImageWidgetTransferFunction<TPixel>
 {
  public:
   /** Standard typedefs */
-  typedef ImageWidgetAffineTransfertFunction   Self;
-  typedef ImageWidgetTransfertFunction<TPixel> Superclass;
+  typedef ImageWidgetAffineTransferFunction   Self;
+  typedef ImageWidgetTransferFunction<TPixel> Superclass;
   typedef itk::SmartPointer<Self>              Pointer;
   typedef itk::SmartPointer<const Self>        ConstPointer;
   
@@ -103,7 +103,7 @@ class ITK_EXPORT ImageWidgetAffineTransfertFunction
   itkNewMacro(Self);
   
   /** Creation through object factory macro */
-  itkTypeMacro(ImageWidgetAffineTransfertFunction,ImageWidgetTransfertFunction);
+  itkTypeMacro(ImageWidgetAffineTransferFunction,ImageWidgetTransferFunction);
   
   /** Template parameters typedefs */
   typedef TPixel PixelType;
@@ -126,25 +126,25 @@ class ITK_EXPORT ImageWidgetAffineTransfertFunction
     }
  protected:
   /** Constructor and  destructor */
-  ImageWidgetAffineTransfertFunction(){}
-  ~ImageWidgetAffineTransfertFunction(){}
+  ImageWidgetAffineTransferFunction(){}
+  ~ImageWidgetAffineTransferFunction(){}
  private:
-  ImageWidgetAffineTransfertFunction(const Self&); //purposely not implemented
+  ImageWidgetAffineTransferFunction(const Self&); //purposely not implemented
   void operator=(const Self&); //purposely not implemented
 };
 
 
-/** \class ImageWidgetSquareRootTransfertFunction
+/** \class ImageWidgetSquareRootTransferFunction
  *  \brief SquareRoot transfert function.
  */
 template <class TPixel>
-class ITK_EXPORT ImageWidgetSquareRootTransfertFunction
-  : public ImageWidgetTransfertFunction<TPixel>
+class ITK_EXPORT ImageWidgetSquareRootTransferFunction
+  : public ImageWidgetTransferFunction<TPixel>
 {
  public:
   /** Standard typedefs */
-  typedef ImageWidgetSquareRootTransfertFunction Self;
-  typedef ImageWidgetTransfertFunction<TPixel>   Superclass;
+  typedef ImageWidgetSquareRootTransferFunction Self;
+  typedef ImageWidgetTransferFunction<TPixel>   Superclass;
   typedef itk::SmartPointer<Self>                Pointer;
   typedef itk::SmartPointer<const Self>          ConstPointer;
   
@@ -152,7 +152,7 @@ class ITK_EXPORT ImageWidgetSquareRootTransfertFunction
   itkNewMacro(Self);
   
   /** Creation through object factory macro */
-  itkTypeMacro(ImageWidgetSquareRootTransfertFunction,ImageWidgetTransfertFunction);
+  itkTypeMacro(ImageWidgetSquareRootTransferFunction,ImageWidgetTransferFunction);
   
   /** Template parameters typedefs */
   typedef TPixel PixelType;
@@ -177,25 +177,25 @@ class ITK_EXPORT ImageWidgetSquareRootTransfertFunction
     }
  protected:
   /** Constructor and  destructor */
-  ImageWidgetSquareRootTransfertFunction(){}
-  ~ImageWidgetSquareRootTransfertFunction(){}
+  ImageWidgetSquareRootTransferFunction(){}
+  ~ImageWidgetSquareRootTransferFunction(){}
  private:
-  ImageWidgetSquareRootTransfertFunction(const Self&); //purposely not implemented
+  ImageWidgetSquareRootTransferFunction(const Self&); //purposely not implemented
   void operator=(const Self&); //purposely not implemented
 };
 
 
-/** \class ImageWidgetLogTransfertFunction
+/** \class ImageWidgetLogTransferFunction
  *  \brief Log transfert function.
  */
 template <class TPixel>
-class ITK_EXPORT ImageWidgetLogTransfertFunction
-  : public ImageWidgetTransfertFunction<TPixel>
+class ITK_EXPORT ImageWidgetLogTransferFunction
+  : public ImageWidgetTransferFunction<TPixel>
 {
  public:
   /** Standard typedefs */
-  typedef ImageWidgetLogTransfertFunction      Self;
-  typedef ImageWidgetTransfertFunction<TPixel> Superclass;
+  typedef ImageWidgetLogTransferFunction      Self;
+  typedef ImageWidgetTransferFunction<TPixel> Superclass;
   typedef itk::SmartPointer<Self>              Pointer;
   typedef itk::SmartPointer<const Self>        ConstPointer;
   
@@ -203,7 +203,7 @@ class ITK_EXPORT ImageWidgetLogTransfertFunction
   itkNewMacro(Self);
   
   /** Creation through object factory macro */
-  itkTypeMacro(ImageWidgetLogTransfertFunction,ImageWidgetTransfertFunction);
+  itkTypeMacro(ImageWidgetLogTransferFunction,ImageWidgetTransferFunction);
   
   /** Template parameters typedefs */
   typedef TPixel PixelType;
@@ -228,24 +228,24 @@ class ITK_EXPORT ImageWidgetLogTransfertFunction
     }
  protected:
   /** Constructor and  destructor */
-  ImageWidgetLogTransfertFunction(){}
-  ~ImageWidgetLogTransfertFunction(){}
+  ImageWidgetLogTransferFunction(){}
+  ~ImageWidgetLogTransferFunction(){}
  private:
-  ImageWidgetLogTransfertFunction(const Self&); //purposely not implemented
+  ImageWidgetLogTransferFunction(const Self&); //purposely not implemented
   void operator=(const Self&); //purposely not implemented
 };
 
-/** \class ImageWidgetSquareTransfertFunction
+/** \class ImageWidgetSquareTransferFunction
  *  \brief Log transfert function.
  */
 template <class TPixel>
-class ITK_EXPORT ImageWidgetSquareTransfertFunction
-  : public ImageWidgetTransfertFunction<TPixel>
+class ITK_EXPORT ImageWidgetSquareTransferFunction
+  : public ImageWidgetTransferFunction<TPixel>
 {
  public:
   /** Standard typedefs */
-  typedef ImageWidgetSquareTransfertFunction      Self;
-  typedef ImageWidgetTransfertFunction<TPixel> Superclass;
+  typedef ImageWidgetSquareTransferFunction      Self;
+  typedef ImageWidgetTransferFunction<TPixel> Superclass;
   typedef itk::SmartPointer<Self>              Pointer;
   typedef itk::SmartPointer<const Self>        ConstPointer;
   
@@ -253,7 +253,7 @@ class ITK_EXPORT ImageWidgetSquareTransfertFunction
   itkNewMacro(Self);
   
   /** Creation through object factory macro */
-  itkTypeMacro(ImageWidgetSquareTransfertFunction,ImageWidgetTransfertFunction);
+  itkTypeMacro(ImageWidgetSquareTransferFunction,ImageWidgetTransferFunction);
   
   /** Template parameters typedefs */
   typedef TPixel PixelType;
@@ -279,10 +279,10 @@ class ITK_EXPORT ImageWidgetSquareTransfertFunction
     }
  protected:
   /** Constructor and  destructor */
-  ImageWidgetSquareTransfertFunction(){}
-  ~ImageWidgetSquareTransfertFunction(){}
+  ImageWidgetSquareTransferFunction(){}
+  ~ImageWidgetSquareTransferFunction(){}
  private:
-  ImageWidgetSquareTransfertFunction(const Self&); //purposely not implemented
+  ImageWidgetSquareTransferFunction(const Self&); //purposely not implemented
   void operator=(const Self&); //purposely not implemented
 };
 }// End namespace otb
diff --git a/Code/Visu/otbImageViewerBase.h b/Code/Visu/otbImageViewerBase.h
index 6018ab607747c22fbc2b040d03fe3bfc4c15345b..f47e57b517f9afd538e0dc8de9e406e4b26bee11 100644
--- a/Code/Visu/otbImageViewerBase.h
+++ b/Code/Visu/otbImageViewerBase.h
@@ -23,7 +23,7 @@ PURPOSE.  See the above copyright notices for more information.
 #include "otbImageViewerScrollWidget.h"
 #include "otbImageViewerZoomWidget.h"
 #include "otbImageViewerFullWidget.h"
-#include "otbImageViewerHistogramAndTransfertFunctionWidget.h"
+#include "otbImageViewerHistogramAndTransferFunctionWidget.h"
 #include "otbStreamingShrinkImageFilter.h"
 #include "otbImageWidgetBoxForm.h"
 #include "otbImageWidgetPolygonForm.h"
@@ -90,9 +90,9 @@ namespace otb
       typedef Fl_Output * FlOutputPointerType;
 
       typedef typename ScrollWidgetType::ImageType ImageType;
-      typedef typename ScrollWidgetType::TransfertFunctionListType TransfertFunctionListType;
-      typedef typename TransfertFunctionListType::Pointer TransfertFunctionListPointerType;
-      typedef typename ScrollWidgetType::AffineTransfertFunctionType AffineTransfertFunctionType;
+      typedef typename ScrollWidgetType::TransferFunctionListType TransferFunctionListType;
+      typedef typename TransferFunctionListType::Pointer TransferFunctionListPointerType;
+      typedef typename ScrollWidgetType::AffineTransferFunctionType AffineTransferFunctionType;
       typedef typename ImageType::Pointer ImagePointerType;
       typedef typename ImageType::IndexType IndexType;
       typedef typename ImageType::PointType PointType;
@@ -118,7 +118,7 @@ namespace otb
       typedef otb::ObjectList<HistogramGeneratorType> HistogramGeneratorListType;
       typedef typename HistogramGeneratorListType::Pointer HistogramGeneratorListPointerType;
       typedef typename HistogramGeneratorType::HistogramType HistogramType;
-      typedef otb::ImageViewerHistogramAndTransfertFunctionWidget<HistogramType,InputPixelType,LabelType> HistogramWidgetType;
+      typedef otb::ImageViewerHistogramAndTransferFunctionWidget<HistogramType,InputPixelType,LabelType> HistogramWidgetType;
       typedef typename HistogramWidgetType::Pointer HistogramWidgetPointerType;
 
       /// Support for conversion from otb::Image to otb::VectorImage
@@ -216,7 +216,7 @@ namespace otb
       itkGetMacro(UseImageOverlay,bool);
       itkSetMacro(ShowHistograms,bool);
       itkGetMacro(ShowHistograms,bool);
-      itkGetObjectMacro(TransfertFunctionList,TransfertFunctionListType);
+      itkGetObjectMacro(TransferFunctionList,TransferFunctionListType);
 
 
       /** Set the input image (VectorImage version) */
@@ -343,7 +343,7 @@ namespace otb
        /**
        * Force redraw
        */
-      virtual void ChangeTransfertFunctions(void);
+      virtual void ChangeTransferFunctions(void);
 
       /**
        * Add a new color-label combination in the ROI color map. Note
@@ -486,8 +486,8 @@ namespace otb
       bool m_UseImageOverlay;
       /// List of histogram generators (one per channel)
       HistogramGeneratorListPointerType m_HistogramGeneratorList;
-      /// Transfert function list
-      TransfertFunctionListPointerType m_TransfertFunctionList;
+      /// Transfer function list
+      TransferFunctionListPointerType m_TransferFunctionList;
 
       /// Histogram widgets
       HistogramWidgetPointerType m_RedHistogramWidget;
diff --git a/Code/Visu/otbImageViewerHistogramAndTransfertFunctionWidget.h b/Code/Visu/otbImageViewerHistogramAndTransfertFunctionWidget.h
index 57d24193e503dd4acb50b272876e71afd718172f..c2f8aebaa5d168953962aa85aba901fb19b3da19 100644
--- a/Code/Visu/otbImageViewerHistogramAndTransfertFunctionWidget.h
+++ b/Code/Visu/otbImageViewerHistogramAndTransfertFunctionWidget.h
@@ -15,10 +15,10 @@ the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 PURPOSE.  See the above copyright notices for more information.
 
 =========================================================================*/
-#ifndef _otbImageViewerHistogramAndTransfertFunctionWidget_h
-#define _otbImageViewerHistogramAndTransfertFunctionWidget_h
+#ifndef _otbImageViewerHistogramAndTransferFunctionWidget_h
+#define _otbImageViewerHistogramAndTransferFunctionWidget_h
 
-#include "otbHistogramAndTransfertFunctionWidget.h"
+#include "otbHistogramAndTransferFunctionWidget.h"
 
 namespace otb
 {
@@ -26,20 +26,20 @@ template <class TPixel, class TLabel> class ImageViewerBase;
 /** 
  * \brief Custom histogram widget for the image viewer.
  *
  * This class derives from otb::HistogramAndTransfertFunctionWidget, 
  * and implements behaviours specific to the image viewer.
  *
- * \sa ImageViewer, HistogramAndTransfertFunctionWidget
+ * \sa ImageViewer, HistogramAndTransferFunctionWidget
  *
  */
 template <class THistogram, class TPixel, class TLabel>
-class ITK_EXPORT ImageViewerHistogramAndTransfertFunctionWidget
-  : public HistogramAndTransfertFunctionWidget<THistogram,TPixel>
+class ITK_EXPORT ImageViewerHistogramAndTransferFunctionWidget
+  : public HistogramAndTransferFunctionWidget<THistogram,TPixel>
   {
     public:
   /** Standard typedefs */
-  typedef ImageViewerHistogramAndTransfertFunctionWidget         Self;
-  typedef HistogramAndTransfertFunctionWidget<THistogram,TPixel> Superclass;
+  typedef ImageViewerHistogramAndTransferFunctionWidget         Self;
+  typedef HistogramAndTransferFunctionWidget<THistogram,TPixel> Superclass;
   typedef itk::SmartPointer<Self>                                Pointer;
   typedef itk::SmartPointer<const Self>                          ConstPointer;
   
@@ -47,7 +47,7 @@ class ITK_EXPORT ImageViewerHistogramAndTransfertFunctionWidget
   itkNewMacro(Self);
   
   /** Creation through object factory macro */
-  itkTypeMacro(ImageViewerHistogramAndTransfertFunctionWidget,HistogramAndTransfertFunctionWidget);
+  itkTypeMacro(ImageViewerHistogramAndTransferFunctionWidget,HistogramAndTransferFunctionWidget);
 
   /** Parent app typedefs */
   typedef TPixel PixelType;
@@ -55,15 +55,15 @@ class ITK_EXPORT ImageViewerHistogramAndTransfertFunctionWidget
   typedef ImageViewerBase<PixelType, LabelType> ParentType;
   typedef ParentType* ParentPointerType;
 
-  typedef typename Superclass::TransfertFunctionPointerType TransfertFunctionPointerType;
-  typedef ImageWidgetAffineTransfertFunction<PixelType> AffineTransfertFunctionType;
-  typedef typename AffineTransfertFunctionType::Pointer AffineTransfertFunctionPointerType;
-  typedef ImageWidgetSquareRootTransfertFunction<PixelType> SquareRootTransfertFunctionType;
-  typedef typename SquareRootTransfertFunctionType::Pointer SquareRootTransfertFunctionPointerType;
-  typedef ImageWidgetLogTransfertFunction<PixelType> LogTransfertFunctionType;
-  typedef typename LogTransfertFunctionType::Pointer LogTransfertFunctionPointerType;
-  typedef ImageWidgetSquareTransfertFunction<PixelType> SquareonentialTransfertFunctionType;
-  typedef typename SquareonentialTransfertFunctionType::Pointer SquareonentialTransfertFunctionPointerType;
+  typedef typename Superclass::TransferFunctionPointerType TransferFunctionPointerType;
+  typedef ImageWidgetAffineTransferFunction<PixelType> AffineTransferFunctionType;
+  typedef typename AffineTransferFunctionType::Pointer AffineTransferFunctionPointerType;
+  typedef ImageWidgetSquareRootTransferFunction<PixelType> SquareRootTransferFunctionType;
+  typedef typename SquareRootTransferFunctionType::Pointer SquareRootTransferFunctionPointerType;
+  typedef ImageWidgetLogTransferFunction<PixelType> LogTransferFunctionType;
+  typedef typename LogTransferFunctionType::Pointer LogTransferFunctionPointerType;
+  typedef ImageWidgetSquareTransferFunction<PixelType> SquareonentialTransferFunctionType;
+  typedef typename SquareonentialTransferFunctionType::Pointer SquareonentialTransferFunctionPointerType;
     
   /** Set the parent application */
   itkSetMacro(Parent,ParentPointerType);
@@ -75,8 +75,8 @@ class ITK_EXPORT ImageViewerHistogramAndTransfertFunctionWidget
     {
       double factor = (this->GetHistogram()->Quantile(0,1.)-this->GetHistogram()->Quantile(0,0.))
 	/(static_cast<double>(this->w())-2*this->GetMarginX()-this->GetOutputHistogramMargin()*static_cast<double>(this->w()));
-      double xupper = this->GetMarginX() + static_cast<double>(this->GetTransfertFunction()->GetUpperBound()-this->GetHistogram()->Quantile(0,0.))/factor;
-      double xlower = this->GetMarginX() + static_cast<double>(this->GetTransfertFunction()->GetLowerBound()-this->GetHistogram()->Quantile(0,0.))/factor;
+      double xupper = this->GetMarginX() + static_cast<double>(this->GetTransferFunction()->GetUpperBound()-this->GetHistogram()->Quantile(0,0.))/factor;
+      double xlower = this->GetMarginX() + static_cast<double>(this->GetTransferFunction()->GetLowerBound()-this->GetHistogram()->Quantile(0,0.))/factor;
       switch(event)
 	{
 	case FL_PUSH:
@@ -99,7 +99,7 @@ class ITK_EXPORT ImageViewerHistogramAndTransfertFunctionWidget
 	  {
 	    m_ModifyLower = false;
 	    m_ModifyUpper = false;
-	    m_Parent->ChangeTransfertFunctions();
+	    m_Parent->ChangeTransferFunctions();
 	    m_Parent->Update();
 	    return 1;
 	  }
@@ -110,13 +110,13 @@ class ITK_EXPORT ImageViewerHistogramAndTransfertFunctionWidget
 	    if(m_ModifyLower && (x>this->GetMarginX()) && (x<static_cast<double>(this->w())-this->GetMarginX()-this->GetOutputHistogramMargin()*static_cast<double>(this->w())))
 	      {
 		x = (x>xupper ? xupper : x);
-		this->GetTransfertFunction()->SetLowerBound(static_cast<PixelType>(this->GetHistogram()->Quantile(0,0.)+(x-this->GetMarginX())*factor));
+		this->GetTransferFunction()->SetLowerBound(static_cast<PixelType>(this->GetHistogram()->Quantile(0,0.)+(x-this->GetMarginX())*factor));
 		this->redraw();
 	      }
 	    else if(m_ModifyUpper && (x<static_cast<double>(this->w())-this->GetMarginX()-this->GetOutputHistogramMargin()*static_cast<double>(this->w())))
 	      {
 		x = (x<xlower ? xlower : x);
-		this->GetTransfertFunction()->SetUpperBound(static_cast<PixelType>(this->GetHistogram()->Quantile(0,0.)+(x-this->GetMarginX())*factor));
+		this->GetTransferFunction()->SetUpperBound(static_cast<PixelType>(this->GetHistogram()->Quantile(0,0.)+(x-this->GetMarginX())*factor));
 		this->redraw();
 	      }
 	    return 1;
@@ -126,37 +126,37 @@ class ITK_EXPORT ImageViewerHistogramAndTransfertFunctionWidget
 	    int dy = Fl::event_dy();
 	    if(dy>0)
 	      {
-		m_TransfertFunctionCode++;
+		m_TransferFunctionCode++;
 	      }
 	    else
 	      {
-		m_TransfertFunctionCode--;
+		m_TransferFunctionCode--;
 	      }
-	    m_TransfertFunctionCode = vcl_abs(m_TransfertFunctionCode%4);
-	    TransfertFunctionPointerType newFunction;
-	    switch(m_TransfertFunctionCode)
+	    m_TransferFunctionCode = vcl_abs(m_TransferFunctionCode%4);
+	    TransferFunctionPointerType newFunction;
+	    switch(m_TransferFunctionCode)
 	      {
 	      case 0:
-		newFunction = AffineTransfertFunctionType::New();
-		this->SetTransfertFunctionLabel("Affine");
+		newFunction = AffineTransferFunctionType::New();
+		this->SetTransferFunctionLabel("Affine");
 		break;
 	      case 1:
-		newFunction = SquareRootTransfertFunctionType::New();
-		this->SetTransfertFunctionLabel("Square Root");
+		newFunction = SquareRootTransferFunctionType::New();
+		this->SetTransferFunctionLabel("Square Root");
 		break;
 	      case 2:
-		newFunction = LogTransfertFunctionType::New();
-		this->SetTransfertFunctionLabel("Logarithmic");
+		newFunction = LogTransferFunctionType::New();
+		this->SetTransferFunctionLabel("Logarithmic");
 		break;
 	      case 3:
-		newFunction = SquareonentialTransfertFunctionType::New();
-		this->SetTransfertFunctionLabel("Square");
+		newFunction = SquareonentialTransferFunctionType::New();
+		this->SetTransferFunctionLabel("Square");
 		break;
 	      }
-	    newFunction->SetLowerBound(this->GetTransfertFunction()->GetLowerBound());
-	    newFunction->SetUpperBound(this->GetTransfertFunction()->GetUpperBound());
-	    this->SetTransfertFunction(newFunction);
-	    m_Parent->ChangeTransfertFunctions();
+	    newFunction->SetLowerBound(this->GetTransferFunction()->GetLowerBound());
+	    newFunction->SetUpperBound(this->GetTransferFunction()->GetUpperBound());
+	    this->SetTransferFunction(newFunction);
+	    m_Parent->ChangeTransferFunctions();
 	    m_Parent->Update();
 	    return 1;
 
@@ -165,14 +165,14 @@ class ITK_EXPORT ImageViewerHistogramAndTransfertFunctionWidget
       return 0;
     }
   /** Constructor */
-  ImageViewerHistogramAndTransfertFunctionWidget()
+  ImageViewerHistogramAndTransferFunctionWidget()
     {
       m_ModifyLower = false;
       m_ModifyUpper = false;
-      m_TransfertFunctionCode = 0;
+      m_TransferFunctionCode = 0;
     }
   /** Destructor */
-  virtual ~ImageViewerHistogramAndTransfertFunctionWidget() 
+  virtual ~ImageViewerHistogramAndTransferFunctionWidget() 
     {
       m_Parent = NULL;
     }
@@ -182,12 +182,12 @@ class ITK_EXPORT ImageViewerHistogramAndTransfertFunctionWidget
       Superclass::PrintSelf(os,indent);
     }
   private:
-  ImageViewerHistogramAndTransfertFunctionWidget(const Self&); //purposely not implemented
+  ImageViewerHistogramAndTransferFunctionWidget(const Self&); //purposely not implemented
   void operator=(const Self&); //purposely not implemented
   /** Modify lower/upper threshold flag */
   bool m_ModifyLower;
   bool m_ModifyUpper;
-  int m_TransfertFunctionCode;
+  int m_TransferFunctionCode;
   ParentPointerType m_Parent;
   };
 
@@ -26,20 +26,20 @@ template <class TPixel, class TLabel> class ImageViewerBase;
  * \brief Custom histogram widget for the image viewer.
  *
- * This class derives from otb::HistogramAndTransfertFunctionWidget, 
+ * This class derives from otb::HistogramAndTransferFunctionWidget, 
  * and implements behaviours specific to the image viewer.
  *